/** FileListExplorer (JavaBeans)
 *  @version 1.1
 *  @author VOURIOT Thierry
 *  @email thierry.vouriot@free.fr
 */

import java.awt.event.*;
import java.awt.*;
import java.io.*;
import java.util.*;
import javax.swing.*;
import tvouriot.beans.filelistexplorer.*;

/** Programme de test du JavaBeans FileListExplorer */
public class TestFileListExplorer extends JFrame {
    
    public TestFileListExplorer() {
        this.setLocation(100,100);
        this.setSize(200,400);
        this.getContentPane().add(new PanelFileExplorer());
        this.addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                System.exit(0);
            }
        });
    }
    
    public static void main(String args[]) {
        new TestFileListExplorer().show();
    }
}

/** Panel contenant l'explorateur de fichiers
 */
class PanelFileExplorer extends JPanel {
    
    /** Explorateur de fichier */
    private static final FileListExplorer fle = new FileListExplorer();
    
    /** Constructeur
     * @param frm Fentre principale de l'application
     */
    public PanelFileExplorer() {
        super(new BorderLayout());
        
        HashMap hm = new HashMap();
        hm.put(".TXT",this.getClass().getResource("icon_txt.gif"));
        
        fle.setSpecialIcons(hm);
        hm = null;
        
        fle.setBackground(Color.white);
        fle.setSelectionBackground(new Color(205,205,255));
        fle.setFixedCellWidth(120);
        fle.setSelectionBorderColor(new Color(150,150,200));
        
        final ExplorerToolBar2 tb2 = new ExplorerToolBar2();
        this.add(new JScrollPane(fle),BorderLayout.CENTER);
        this.add(new ExplorerToolBar(),BorderLayout.NORTH);
        this.add(tb2,BorderLayout.SOUTH);
        
        fle.addFileListExplorerListener(new FileListExplorerListener() {
            public void fileSelected(FileListExplorerEvent evt) { }
            public void fileChoosen(FileListExplorerEvent evt) { }
            public void directoryChanged(FileListExplorerEvent evt) {
                tb2.lblNbFiles.setText(fle.getNbFiles()+ " fichier(s) | " + fle.getNbDirectories()+ " dossier(s)");
            }
        });
    }
    
    
    /** Barre d'outils de l'explorateur de fichiers
     */
    private static final class ExplorerToolBar extends JPanel {
        
        private JButton cmdParent = new JButton(new ImageIcon(this.getClass().getResource("icon_parent.gif")));
        private JButton cmdNext = new JButton(new ImageIcon(this.getClass().getResource("icon_repnext.gif")));
        private JButton cmdDel = new JButton(new ImageIcon(this.getClass().getResource("icon_del.gif")));
        private JButton cmdMkdir = new JButton(new ImageIcon(this.getClass().getResource("icon_mkdir.gif")));
        private JButton cmdRefresh = new JButton(new ImageIcon(this.getClass().getResource("icon_refresh.gif")));
        private JTextField txtDir = new JTextField();
        private final Dimension dimSeparator = new Dimension(2,2);
        private final Dimension dimSeparator2 = new Dimension(4,2);
        
        /** Constructeur
         */
        protected ExplorerToolBar() {
            
            this.setLayout(new BorderLayout());
            JToolBar tbC = new JToolBar();
            JToolBar tbS = new JToolBar();
            tbC.setFloatable(false);
            tbS.setFloatable(false);
            
            tbS.add(cmdParent);
            tbS.addSeparator(dimSeparator2);
            tbS.add(cmdNext);
            tbS.addSeparator(dimSeparator2);
            tbS.add(cmdDel);
            tbS.addSeparator(dimSeparator2);
            tbS.add(cmdRefresh);
           
            tbC.add(cmdMkdir);
            tbC.addSeparator(dimSeparator);
            tbC.add(txtDir);
            
            this.add(tbC,BorderLayout.CENTER);
            this.add(tbS,BorderLayout.SOUTH);
            
            cmdParent.addActionListener(new ActionListener() {
                public void actionPerformed(ActionEvent evt) {
                    if (fle.getCurrentDirectory() != null)
                        fle.setCurrentDirectory(fle.getCurrentDirectory().getParentFile());
                }
            });
            cmdNext.addActionListener(new ActionListener() {
                public void actionPerformed(ActionEvent evt) {
                    File f = fle.getSelectedFile();
                    if (f != null && f.isDirectory())
                        fle.setCurrentDirectory(f);
                }
            });
            cmdDel.addActionListener(new ActionListener() {
                public void actionPerformed(ActionEvent evt) {
                    File f = fle.getSelectedFile();
                    if (f != null) {
                        String s;
                        if (f.isDirectory()) {
                            s = "Voulez-vous vraiment supprimer le rpertoire " + f.getName() + " ?";
                            s += "\nAttention le rpertoire doit tre vide !";
                        }
                        else s = "Voulez-vous vraiment supprimer le fichier " + f.getName() + " ?";
                        if (JOptionPane.showConfirmDialog(null,s,"Suppresion",JOptionPane.YES_NO_OPTION) == JOptionPane.OK_OPTION)
                            fle.delete();
                    }
                }
            });
            cmdMkdir.addActionListener(new ActionListener() {
                public void actionPerformed(ActionEvent evt) {
                    String s = txtDir.getText().trim();
                    if (!s.equals("")) {
                        fle.mkDir(s);
                        txtDir.setText("");
                    }
                }
            });
            cmdRefresh.addActionListener(new ActionListener() {
                public void actionPerformed(ActionEvent evt) {
                    fle.refresh();
                }
            });  
        }
    }
    
    /** Barre d'outils de l'explorateur de fichiers
     */
    private static final class ExplorerToolBar2 extends JPanel {
        
        protected JLabel lblNbFiles = new JLabel(" ");
        private JCheckBox chkHidden = new JCheckBox("Afficher les fichiers cachs",true);
        private JComboBox cmbSort = new JComboBox();
        
        /** Constructeur
         */
        protected ExplorerToolBar2() {
            
            cmbSort.addItem("Trier par nom");
            cmbSort.addItem("Trier par extension");
            
            this.setLayout(new BorderLayout());
            JToolBar tbC = new JToolBar();
            JToolBar tbS = new JToolBar();
            JToolBar tbN = new JToolBar();
            tbC.setFloatable(false);
            tbS.setFloatable(false);
            tbN.setFloatable(false);
            
            tbC.add(chkHidden);
            tbN.add(cmbSort);
            tbS.add(lblNbFiles);
            
            this.add(tbC,BorderLayout.CENTER);
            this.add(tbS,BorderLayout.SOUTH);
            this.add(tbN,BorderLayout.NORTH);
           
            chkHidden.addItemListener(new ItemListener() {
                public void itemStateChanged(java.awt.event.ItemEvent itemEvent) {
                    if (chkHidden.isSelected())
                        fle.setShowHiddenFiles(true);
                    else fle.setShowHiddenFiles(false);
                    fle.refresh();
                }
            });
            cmbSort.addItemListener(new ItemListener() {
                public void itemStateChanged(java.awt.event.ItemEvent itemEvent) {
                    fle.setSortType(cmbSort.getSelectedIndex());
                    fle.refresh();
                }
            });
        }
    }
}